@@ -12,7 +12,6 @@ import pytesseract
 from PIL import Image
 import pytz
 import time
-from dateutil.relativedelta import relativedelta
 
 
 def df_retainCols(dfdata, collist): #deletes columns in df which are not there in list of columns
@@ -608,10 +607,10 @@ class TimeKeeper():
     
     def log(self) -> datetime:
         '''
-        returns difference as relativedelta value of difference between last log and 2nd last log entry
+        returns difference between last log and 2nd last log entry
         '''
         self.logs.append(datetime.datetime.now())
-        diff = relativedelta(self.logs[-1], self.logs[-2])
+        diff = self.logs[-1] - self.logs[-2]
         if self.supress == 'y':
             pass
         else:
@@ -622,9 +621,9 @@ class TimeKeeper():
 
     def get_log(self, log_idx:int) -> datetime:
         '''
-        returns difference as relativedelta value of difference between given log and start time
+        returns difference between given log and start time
         '''
-        diff = relativedelta(self.logs[log_idx], self.start_time)
+        diff = self.logs[log_idx], self.start_time
         if self.supress == 'y':
             pass
         else:
@@ -635,7 +634,7 @@ class TimeKeeper():
     def end(self) -> datetime:
         self.end_time = datetime.datetime.now()
         self.logs.append(self.end_time)
-        diff = relativedelta(self.end_time, self.start_time)
+        diff = self.end_time, self.start_time
         if self.supress == 'y':
             pass
         else:
